==========================
Machine Code for Beginners
==========================

.. image:: cover.jpg

`Download the original book <https://drive.google.com/open?id=0Bxv0SsvibDMTcHNXalEtYkVtU00>`__

